==> cesar-p-2.2.0.tar.gz: cesar-p-2.2.0/src/cesarp/common/DatasetMetadata.py <==
# coding=utf-8
#
# Copyright (c) 2022, Empa, Leonie Fierz, Aaron Bojarski, Ricardo Parreira da Silva, Sven Eggimann.
#
# This file is part of CESAR-P - Combined Energy Simulation And Retrofit written in Python
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
#
# Contact: https://www.empa.ch/web/s313
#
from typing import Dict
from datetime import datetime
from cesarp.common.version_info import get_version_info


class DatasetMetadata:
    def __init__(
        self,
        source: str,
        source_link: str = None,
        date_created=datetime.now(),
        description=None,
        config_entries: Dict = {},
    ):
        self.SOURCE = source
        self.SOURCE_LINK = source_link
        self.DESCRIPTION = description
        self.DATE_CREATED = date_created
        self.CONFIG_ENTRIES = config_entries
        self.VERSION_INFO = get_version_info()

    def get_as_dict(self):
        return self.__dict__

    @classmethod
    def emptyObj(cls):
        return cls(None, None, None, None, None)

==> cesar-p-2.3.0.tar.gz: cesar-p-2.3.0/src/cesarp/common/DatasetMetadata.py <==
# coding=utf-8
#
# Copyright (c) 2022, Empa, Leonie Fierz, Aaron Bojarski, Ricardo Parreira da Silva, Sven Eggimann.
#
# This file is part of CESAR-P - Combined Energy Simulation And Retrofit written in Python
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
#
# Contact: https://www.empa.ch/web/s313
#
from typing import Dict
from datetime import datetime
from cesarp.common.version_info import get_version_info


class DatasetMetadata:
    def __init__(
        self,
        source: str,
        source_link: str = None,
        date_created=datetime.now(),
        description=None,
        config_entries: Dict = None,
    ):
        self.SOURCE = source
        self.SOURCE_LINK = source_link
        self.DESCRIPTION = description
        self.DATE_CREATED = date_created
        if config_entries is None:
            config_entries = {}
        self.CONFIG_ENTRIES = config_entries
        self.VERSION_INFO = get_version_info()

    def get_as_dict(self):
        return self.__dict__

    @classmethod
    def emptyObj(cls):
        return cls(None, None, None, None, None)
